Enumeration
QmiImspEnablerState
since: 1.34
Members
-
QMI_IMSP_ENABLER_STATE_UNINITIALIZED -
IMS is not initialized yet.
- Value:
1 - Available since: 1.34
- Value:
-
QMI_IMSP_ENABLER_STATE_INITIALIZED -
IMS is initialized, but not registered yet with the network IMS service.
- Value:
2 - Available since: 1.34
- Value:
-
QMI_IMSP_ENABLER_STATE_AIRPLANE -
IMS is initialized but device is in airplane mode.
- Value:
3 - Available since: 1.34
- Value:
-
QMI_IMSP_ENABLER_STATE_REGISTERED -
IMS is initialized and registered.
- Value:
4 - Available since: 1.34
- Value:
Type functions
qmi_imsp_enabler_state_get_string
Gets the nickname string for the QmiImspEnablerState specified at val.
since: 1.34